require "import" import "android.widget.*" import "android.view.*" import "android.content.Context" import "android.content.ClipData" import "android.content.ClipboardManager" import "android.net.Uri" import "android.content.Intent" import "android.graphics.Typeface" import "android.graphics.BitmapFactory" import "android.app.DownloadManager" import "android.os.Environment" import "cjson"

activity = this

function vibrate()
    local vibrator = activity.getSystemService(Context.VIBRATOR_SERVICE)
    if vibrator then
        vibrator.vibrate(30)
    end
end

function dp(dps)
    return tonumber(dps) * activity.getResources().getDisplayMetrics().density
end

function copyToClipboard(text)
    local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
    local clip = ClipData.newPlainText("Copied Text", text)
    clipboard.setPrimaryClip(clip)
    service.speak("Tautan berhasil disalin!")
end

function downloadMedia(url, fileName, mimeType)
    local success, err = pcall(function()
        local downloadManager = activity.getSystemService(Context.DOWNLOAD_SERVICE)
        local request = DownloadManager.Request(Uri.parse(url))

        request.setMimeType(mimeType)
        request.setTitle(fileName)
        request.setDescription("Mengunduh " .. fileName)
        request.setNotificationVisibility(DownloadManager.Request.VISIBILITY_VISIBLE_NOTIFY_COMPLETED)
        request.setDestinationInExternalPublicDir(Environment.DIRECTORY_DOWNLOADS, fileName)

        downloadManager.enqueue(request)
        service.speak("Unduhan dimulai: " .. fileName)
    end)
    if not success then
        service.speak("Gagal memulai unduhan: " .. err)
    end
end

function generateMetaAIMedia(prompt)
    local baseUrl = "https://api.fasturl.link/aiimage/meta"
    local apiUrl = string.format("%s?prompt=%s&mode=animated", baseUrl, Uri.encode(prompt))

    Http.get(apiUrl, {}, function(code, content)
        if code == 200 then
            local success, jsonResponse = pcall(cjson.decode, content)
            if success and jsonResponse and jsonResponse.status == 200 and jsonResponse.content == "Success" then
                displayGeneratedMedia(jsonResponse.result)
service.speak("Media berhasil dibuat!")
            else
service.speak("Gagal membuat media atau respons tidak valid.")
                mediaContainer.removeAllViews()
                local tv = TextView(activity)
                tv.setText("Tidak ada media yang dihasilkan untuk prompt ini.")
                tv.setTextSize(16)
                mediaContainer.addView(tv)
            end
        else
service.speak("Gagal mengakses API: Kode HTTP " .. code)
            mediaContainer.removeAllViews()
            local tv = TextView(activity)
            tv.setText("Gagal mengakses API: Kode HTTP " .. code)
            tv.setTextSize(16)
            mediaContainer.addView(tv)
        end
    end)
end

function displayGeneratedMedia(result)
    mediaContainer.removeAllViews()

    if result.imagine_card then
        local imagineCard = result.imagine_card[1]
        if imagineCard and imagineCard.imagine_media then
            local tvHeader = TextView(activity)
            tvHeader.setText("Gambar:")
            tvHeader.setTextSize(18)
            tvHeader.setTypeface(nil, Typeface.BOLD)
            mediaContainer.addView(tvHeader)

            for i, media in ipairs(imagineCard.imagine_media) do
                if media.media_type == "IMAGE" then
                    local imageLayout = LinearLayout(activity)
                    imageLayout.setOrientation(LinearLayout.HORIZONTAL)
                    imageLayout.setGravity(Gravity.CENTER_VERTICAL)
                    imageLayout.setPadding(0, 10, 0, 10)

                    local imageView = ImageView(activity)
                    Http.get(media.uri, {}, function(code, imageContent)
                        if code == 200 then
                            local byte_array_content = nil
                            if pcall(function() byte_array_content = luaj.newbytearray(imageContent) end) then
                                -- Success using luaj.newbytearray (common in ASE)
                            elseif pcall(function() byte_array_content = java.new(luaj.array(luaj.byte), imageContent) end) then
                                -- Alternative for some Luaj-based environments
                            else
                                byte_array_content = imageContent
                            end

                            local bm = nil
                            local decode_success, decode_err = pcall(function()
                                bm = BitmapFactory.decodeByteArray(byte_array_content, 0, #imageContent)
                            end)

                            if decode_success and bm then
                                imageView.setImageBitmap(bm)
                           else
                                imageView.setImageDrawable(activity.getResources().getDrawable(android.R.drawable.ic_menu_close_clear_cancel))
                            end
                        else
service.speak("Gagal memuat gambar dari URL: Kode HTTP " .. code)
                            imageView.setImageDrawable(activity.getResources().getDrawable(android.R.drawable.ic_menu_gallery))
                        end
                    end)
                    local layoutParamsImage = LinearLayout.LayoutParams(dp(100), dp(100))
                    layoutParamsImage.setMargins(0, 0, dp(10), 0)
                    imageView.setLayoutParams(layoutParamsImage)
                    imageLayout.addView(imageView)

                    local downloadButton = Button(activity)
                    downloadButton.setText("Unduh Gambar")
                    downloadButton.setOnClickListener(function()
                        local fileName = "ai_image_" .. os.time() .. "_" .. i .. ".png"
                        downloadMedia(media.uri, fileName, "image/png")
                    end)
                    imageLayout.addView(downloadButton)

                    mediaContainer.addView(imageLayout)
                end
            end
        end
    end

    if result.animated_media then
        local tvHeader = TextView(activity)
        tvHeader.setText("Video (Animated):")
        tvHeader.setTextSize(18)
        tvHeader.setTypeface(nil, Typeface.BOLD)
        tvHeader.setPadding(0, 20, 0, 0)
        mediaContainer.addView(tvHeader)

        for i, media in ipairs(result.animated_media) do
            if media.type == "VIDEO" then
                local videoLayout = LinearLayout(activity)
                videoLayout.setOrientation(LinearLayout.HORIZONTAL)
                videoLayout.setGravity(Gravity.CENTER_VERTICAL)
                videoLayout.setPadding(0, 10, 0, 10)

                local videoTitle = TextView(activity)
                videoTitle.setText("Video: " .. media.prompt)
                videoTitle.setLayoutParams(LinearLayout.LayoutParams(0, ViewGroup.LayoutParams.WRAP_CONTENT, 1.0))
                videoLayout.addView(videoTitle)

                local downloadButton = Button(activity)
                downloadButton.setText("Unduh Video")
                downloadButton.setOnClickListener(function()
                    local fileName = "ai_video_" .. os.time() .. "_" .. i .. ".mp4"
                    downloadMedia(media.url, fileName, "video/mp4")
                end)
                videoLayout.addView(downloadButton)

                mediaContainer.addView(videoLayout)
            end
        end
    end

    if not result.imagine_card and not result.animated_media then
        local tv = TextView(activity)
        tv.setText("Tidak ada media yang dihasilkan untuk prompt ini.")
        tv.setTextSize(16)
        mediaContainer.addView(tv)
    end
end

layout = {
    LinearLayout,
    orientation = "vertical",
    layout_width = "fill",
    layout_height = "fill",
    padding = "16dp",
    {
        TextView,
        id = "headerText",
        text = "Hasilkan gambar dan video AI menggunakan prompt.",
        textSize = "16sp",
        layout_width = "fill",
        layout_height = "wrap_content",
        gravity = "center",
        padding = "10dp"
    },
    {
        EditText,
        id = "promptInput",
        hint = "Masukkan Prompt (contoh: Cute Antro Furry Cub)",
        layout_width = "fill",
        layout_height = "wrap_content",
        padding = "10dp"
    },
    {
        Button,
        id = "generateButton",
        text = "Hasilkan Media AI",
        layout_width = "fill",
        layout_height = "wrap_content",
        onClick = function() vibrate()
            local prompt = promptInput.getText().toString()

            if #prompt == 0 then
service.speak("Masukkan prompt untuk menghasilkan media!")
                return
            end

service.speak("Menghasilkan media untuk '" .. prompt .. "'...")
            generateMetaAIMedia(prompt)
        end
    },
    {
        ScrollView,
        layout_width = "fill",
        layout_height = "fill",
        {
            LinearLayout,
            id = "mediaContainer",
            orientation = "vertical",
            layout_width = "fill",
            layout_height = "wrap_content",
            padding = "10dp"
       }
    },
      {
        Button,
        text = "Tentang, dapatkan pembaruan",
        layout_width = "match",
        layout_height = "wrap_content",
        layout_margin = "16dp",
onClick = function() dev()
end
}
}

function dev()
    local aboutLayout = {
        ScrollView,
        layout_width = "fill",
        layout_height = "fill",
        backgroundColor = 0xFF121212,
        {
            LinearLayout,
            orientation = "vertical",
            layout_width = "fill",
            layout_height = "wrap",
            padding = "16dp",
            {
                TextView,
                text = "Bergabung ke saluran saya untuk mendapatkan alat plugin Jieshuo lainnya.\n\nRequest report, dll tentang ekstensi. Silakan hubungi saya",
                layout_width = "fill",
                layout_height = "wrap_content",
                textSize = "20sp",
                textColor = 0xFFFFFFFF,
                gravity = "center",
                backgroundColor = 0xFF6200EE,
                padding = "12dp"
},
            {
                Button,
                text = "Contact Developer",
                layout_width = "fill",
                layout_height = "wrap",
                backgroundColor = 0xFF03DAC5,
                textColor = 0xFF000000,
                padding = "12dp",
                onClick = function()
                    vibrate()
                    pcall(function()
                        service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("tg://resolve?domain=jibomico")))
                    end)
                    service.speak("Membuka Telegram...")
                    aboutDlg.dismiss()
                    dlg.dismiss()
                end
},
            {
                Button,
                text = "Bergabung ke channel Telegram",
                layout_width = "fill",
                layout_height = "wrap",
                backgroundColor = 0xFFBB86FC,
                textColor = 0xFFFFFFFF,
                padding = "12dp",
                onClick = function()
                    vibrate()
                    pcall(function()
                        service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("tg://resolve?domain=jieshuojm")))
                    end)
                    service.speak("Membuka channel Telegram...")
                    aboutDlg.dismiss()
                    dlg.dismiss()
                end
},
            {
                Button,
                text = "Bergabung ke grup WhatsApp",
                layout_width = "fill",
                layout_height = "wrap",
                backgroundColor = 0xFF6200EE,
                textColor = 0xFFFFFFFF,
                padding = "12dp",
onClick = function()
                    vibrate()
                    pcall(function()
                        service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("https://chat.whatsapp.com/EXsCeLRcy9I3njvaqeIn7x")))
                    end)
                    service.speak("Membuka grup WhatsApp...")
                    aboutDlg.dismiss()
                    dlg.dismiss()
                end
}
}
}

    aboutDlg = LuaDialog(activity)
    aboutDlg.setTitle("Developed by Jm")
    aboutDlg.setView(loadlayout(aboutLayout))
    aboutDlg.setButton("Ok", function()
        aboutDlg.dismiss()
        vibrate()
    end)
   vibrate() aboutDlg.show()
end

dlg = LuaDialog(activity)
dlg.setTitle("MetaAI Media Generator")
dlg.setView(loadlayout(layout))
dlg.setButton("Tutup", function()
    dlg.dismiss()
end)
dlg.show()


